#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 4/1/21

# Inspire by a Photoshop tutorial found here: https://www.photoshopessentials.com/photo-effects/shape-cluster-photo-display-with-photoshop-cc/

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY# without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.   

from gimpfu import *
import gettext
import os, sys,time 

gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_create_shape_cluster_photo_display(filename):
        
    #Initiates the temporary state
    pdb.gimp_context_set_defaults()
    pdb.gimp_context_set_default_colors()
	
	#Create the background sky
    img = pdb.gimp_image_new(1525, 1525, RGB)
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGB_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, backLayer, 0)
    pdb.gimp_layer_add_alpha(backLayer)
    pdb.gimp_context_set_foreground("White")
    pdb.gimp_drawable_fill(backLayer, FILL_FOREGROUND)
    
    #Image process
    pdb.gimp_display_new(img)
    
    #Open a photo
    imagLayer = pdb.gimp_file_load_layer(img, filename)
    pdb.gimp_layer_add_alpha(imagLayer)
    pdb.gimp_image_add_layer(img, imagLayer, 0)       
    pdb.gimp_image_set_active_layer(img, imagLayer)
    if imagLayer:
        pdb.gimp_layer_scale(imagLayer, 1400, 1400, TRUE)
    pdb.gimp_item_set_name(imagLayer, "Image") 
    
    #Center the image to the background
    x = imagLayer.offsets[0]
    y = imagLayer.offsets[1]
    x = (img.width - imagLayer.width) / 2 
    y = (img.height - imagLayer.height) / 2
    imagLayer.set_offsets(x, y)
    pdb.gimp_layer_resize_to_image_size(imagLayer)
      
    #Shapes
    shapesLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Shapes", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, shapesLayer, 0)
    pdb.gimp_layer_add_alpha(shapesLayer)
    pdb.gimp_drawable_fill(shapesLayer, FILL_TRANSPARENT)

   #Top left piece
    pdb.gimp_image_select_rectangle(img, 2, 62, 62, 471, 933)
    offx = -25
    offy = -25
    non_empty = pdb.gimp_edit_cut(imagLayer)
    pdb.gimp_selection_translate(img, offx, offy)
    shapesLayer = pdb.gimp_edit_paste(shapesLayer, FALSE)
    pdb.gimp_layer_scale(shapesLayer, 471, 957, FALSE)
    pdb.gimp_floating_sel_anchor(shapesLayer) 
    shapesLayer = pdb.gimp_image_get_layer_by_name(img, "Shapes")
    
    #Top right piece
    pdb.gimp_image_select_rectangle(img, 2, 534, 62, 933, 471)
    offx = -5
    offy = -25
    non_empty = pdb.gimp_edit_cut(imagLayer)
    pdb.gimp_selection_translate(img, offx, offy)
    shapesLayer = pdb.gimp_edit_paste(shapesLayer, FALSE)
    
    pdb.gimp_layer_scale(shapesLayer, 950, 471, FALSE)
    pdb.gimp_floating_sel_anchor(shapesLayer) 
    shapesLayer = pdb.gimp_image_get_layer_by_name(img, "Shapes")
    
    #Bottom left piece
    pdb.gimp_image_select_rectangle(img, 2, 62, 995, 936, 467)
    offx = -25
    offy = 25
    non_empty = pdb.gimp_edit_cut(imagLayer)
    pdb.gimp_selection_translate(img, offx, offy)
    shapesLayer = pdb.gimp_edit_paste(shapesLayer, FALSE)
    pdb.gimp_layer_scale(shapesLayer, 959, 469, FALSE)
    pdb.gimp_floating_sel_anchor(shapesLayer) 
    shapesLayer = pdb.gimp_image_get_layer_by_name(img, "Shapes")

    #Bottom right
    pdb.gimp_image_select_rectangle(img, 2, 998, 534, 464, 930)
    non_empty = pdb.gimp_edit_cut(imagLayer)
    offx = 25
    offy = -15
    pdb.gimp_selection_translate(img, offx, offy)
    shapesLayer = pdb.gimp_edit_paste(shapesLayer, FALSE) 
    pdb.gimp_layer_scale(shapesLayer, 464, 958, FALSE)
    pdb.gimp_floating_sel_anchor(shapesLayer) 
    shapesLayer = pdb.gimp_image_get_layer_by_name(img, "Shapes")
    
    #Center piece
    pdb.gimp_image_select_rectangle(img, 2, 534, 534, 464, 464)
    non_empty = pdb.gimp_edit_cut(imagLayer)
    shapesLayer = pdb.gimp_edit_paste(shapesLayer, FALSE)
    pdb.gimp_floating_sel_anchor(shapesLayer) 
    shapesLayer = pdb.gimp_image_get_layer_by_name(img, "Shapes")
    
    #Remove empty layer
    pdb.gimp_image_remove_layer(img, imagLayer)
    
    #Drop shadow
    pdb.script_fu_drop_shadow(img, shapesLayer, 12, 12, 20, ("Black"), 60, FALSE)
    
    backLayer = pdb.gimp_image_merge_visible_layers(img, CLIP_TO_BOTTOM_LAYER)
    
    backLayer = pdb.gimp_image_get_layer_by_name(img, "Background")
    pdb.gimp_item_set_name(backLayer, "Photo effect")
    pdb.gimp_image_set_active_layer(img, backLayer)
    pdb.gimp_context_set_defaults()
    pdb.gimp_context_set_default_colors()
    	
register(
    "pm_create_shape_cluster_photo_display",
    "Creates a shape cluster display from an image",
    "Creates a shape cluster display from an image",
    "Pocholo",
    "Pocholo",
    "2021",
    "Create a Shape Cluster Photo Display",
    "",
    [
    (PF_FILENAME, "filename", "Image:", None),    
    ],
    [],
    pm_create_shape_cluster_photo_display, menu="<Image>/Pocholo-scripts/Create a Shape Cluster Photo Display",
    domain=("gimp20", gimp.locale_directory))
main()					